@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="el">
 <context>
     <name>AliasTab</name>
     <message>
@@ -22,17 +24,17 @@
     <message>
         <location filename="../othertab.ui" line="41"/>
         <source>Custom</source>
-        <translation>προσαρμόσῃ</translation>
+        <translation>Προσαρμογή</translation>
     </message>
     <message>
         <location filename="../othertab.ui" line="63"/>
         <source>Infinite</source>
-        <translation type="unfinished"/>
+        <translation>Απεριόριστο</translation>
     </message>
     <message>
         <location filename="../othertab.ui" line="75"/>
         <source>Executable Paths</source>
-        <translation type="unfinished"/>
+        <translation>Εκτελέσιμες διαδρομές</translation>
     </message>
     <message>
         <location filename="../othertab.ui" line="84"/>
@@ -55,82 +57,82 @@
     <message>
         <location filename="../prompttab_fix.ui" line="44"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Change what gives you your prompt.&lt;/p&gt;&lt;p&gt;Default - Use what prompt you had before.&lt;/p&gt;&lt;p&gt;Fancy Prompt - Uses the MX Fancy Prompt utility&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Επιλογή αρχής στη γραμμή εντολών.&lt;/p&gt;&lt;p&gt;Προεπιλογή - Όπως ήταν προηγουμένως.&lt;/p&gt;&lt;p&gt;Φαντεζί - Χρήση του εργαλείου MX Fancy Prompt&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="152"/>
         <source>Make The Larger Prompts Smaller</source>
-        <translation type="unfinished"/>
+        <translation>Μικρότερη αρχή στη γραμμή εντολών</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="159"/>
         <source>Muted Colors</source>
-        <translation type="unfinished"/>
+        <translation>Απαλά χρώματα</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="166"/>
         <source>Disable Unicode</source>
-        <translation type="unfinished"/>
+        <translation>Απενεργοποίηση unicode</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="173"/>
         <source>Use Double Lines</source>
-        <translation type="unfinished"/>
+        <translation>Διπλές γραμμές</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="180"/>
         <source>Use Bold Lines</source>
-        <translation type="unfinished"/>
+        <translation>Έντονες γραμμές</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="187"/>
         <source>No Colors(Overrides All Other Color Options)</source>
-        <translation type="unfinished"/>
+        <translation>Χωρίς χρώματα (Καταργεί όλες τις χρωματικές επιλογές)</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="194"/>
         <source>Use Parentheses Instead Of Square Brackets</source>
-        <translation type="unfinished"/>
+        <translation>Παρενθέσεις αντί για αγκύλες</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="201"/>
         <source>Make the Larger Prompts Smaller Elsewhere</source>
-        <translation type="unfinished"/>
+        <translation>Μικρότερη αρχή στη γραμμή εντολών παντού</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="225"/>
         <source>Time Format</source>
-        <translation type="unfinished"/>
+        <translation>Μορφή ώρας</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="267"/>
         <source>Date Format</source>
-        <translation type="unfinished"/>
+        <translation>Μορφή ημερομηνίας</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="315"/>
         <source>Right Margin</source>
-        <translation type="unfinished"/>
+        <translation>Δεξί περιθώριο</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="351"/>
         <source>Extra Newlines Before Prompt</source>
-        <translation type="unfinished"/>
+        <translation>Πρόσθετες γραμμές πριν την αρχή στη γραμμή εντολών</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="380"/>
         <source>Prompt Text</source>
-        <translation type="unfinished"/>
+        <translation>Κείμενο αρχής στη γραμμή εντολών</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="409"/>
         <source>Title Text</source>
-        <translation>Κείμενο Τίτλου</translation>
+        <translation>Κείμενο τίτλου</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="429"/>
         <source>Remove all newlines</source>
-        <translation type="unfinished"/>
+        <translation>Αφαίρεση όλων των νέων γραμμών</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="456"/>
@@ -150,30 +152,30 @@
     <message>
         <location filename="../prompttab_fix.ui" line="518"/>
         <source>Up</source>
-        <translation>σε λειτουργία</translation>
+        <translation>Επάνω</translation>
     </message>
     <message>
         <location filename="../prompttab_fix.ui" line="535"/>
         <source>Down</source>
-        <translation>Μη λειτουργία</translation>
+        <translation>Κάτω</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../prompttab.cpp" line="543"/>
+        <location filename="../prompttab.cpp" line="546"/>
         <source>Foreground Color</source>
-        <translation type="unfinished"/>
+        <translation>Χρώμα κειμένου</translation>
     </message>
     <message>
-        <location filename="../prompttab.cpp" line="544"/>
+        <location filename="../prompttab.cpp" line="547"/>
         <source>Background Color</source>
-        <translation type="unfinished"/>
+        <translation>Χρώμα παρασκηνίου</translation>
     </message>
     <message>
-        <location filename="../prompttab.cpp" line="545"/>
+        <location filename="../prompttab.cpp" line="548"/>
         <source>Bold</source>
-        <translation type="unfinished"/>
+        <translation>Έντονο</translation>
     </message>
 </context>
 <context>
@@ -191,7 +193,7 @@
     <message>
         <location filename="../window_fix.ui" line="85"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Applies Changes.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Εφαρμογή αλλαγών.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../window_fix.ui" line="88"/>
@@ -201,7 +203,7 @@
     <message>
         <location filename="../window_fix.ui" line="99"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Closes the application.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Κλείσιμο της εφαρμογής.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../window_fix.ui" line="102"/>
@@ -211,14 +213,14 @@
     <message>
         <location filename="../window.cpp" line="48"/>
         <source>An easy way to configure your ~/.bashrc and bash prompt</source>
-        <translation type="unfinished"/>
+        <translation>Εύκολος τρόπος διαμόρφωσης του αρχείου ~/.bashrc και της αρχής στη γραμμή ετολών (bash prompt)</translation>
     </message>
     <message>
         <location filename="../window.cpp" line="260"/>
         <location filename="../window.cpp" line="264"/>
         <location filename="../window.cpp" line="268"/>
         <source>Bash Config</source>
-        <translation>Διαμόρφωση Bash</translation>
+        <translation>Διαμόρφωση του bash</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
